@@ -137,6 +137,12 @@ PUT_CALL_RATIO = '/api/v5/rubik/stat/option/open-interest-volume-ratio'
 OPEN_INTEREST_VOLUME_EXPIRY = '/api/v5/rubik/stat/option/open-interest-volume-expiry'
 INTEREST_VOLUME_STRIKE = '/api/v5/rubik/stat/option/open-interest-volume-strike'
 TAKER_FLOW = '/api/v5/rubik/stat/option/taker-block-volume'
+OPEN_INTEREST_HISTORY = '/api/v5/rubik/stat/contracts/open-interest-history'
+LONG_SHORT_ACCOUNT_RATIO_CONTRACT_TOP_TRADER = '/api/v5/rubik/stat/contracts/long-short-account-ratio-contract-top-trader'
+LONG_SHORT_POSITION_RATIO_CONTRACT_TOP_TRADER = '/api/v5/rubik/stat/contracts/long-short-position-ratio-contract-top-trader'
+LONG_SHORT_ACCOUNT_RATIO_CONTRACT = '/api/v5/rubik/stat/contracts/long-short-account-ratio-contract'
+TAKER_VOLUME_CONTRACT = '/api/v5/rubik/stat/taker-volume-contract'
+
 
 # TRADE-Complete
 PLACR_ORDER = '/api/v5/trade/order'
@@ -166,7 +172,7 @@ CONVERT_EASY_HISTORY = '/api/v5/trade/easy-convert-history'
 ONE_CLICK_REPAY_SUPPORT = '/api/v5/trade/one-click-repay-currency-list'
 ONE_CLICK_REPAY = '/api/v5/trade/one-click-repay'
 ONE_CLICK_REPAY_HISTORY = '/api/v5/trade/one-click-repay-history'
-
+CANCEL_ALL_AFTER = '/api/v5/trade/cancel-all-after'
 
 # SubAccount-complete-testwriteComplete
 BALANCE = '/api/v5/account/subaccount/balances'
